@@ -62,11 +62,26 @@ class Client(object):
         self.client.send_pyobj(message)
 
         return_value = self.client.recv_pyobj()
+        return return_value
+
+    def get_res_dataframe(self, *args, **kwargs):
+
+        if 'use_sparse' not in kwargs.keys():
+            kwargs['use_sparse'] = True
+
+        if 'scene' not in kwargs.keys():
+            kwargs['scene'] = 'full'
+
+        self.logger.debug('Getting results from workers...')
+
+        message = Message(method='create_res_dataframe',
+                          kwargs=kwargs)
+
+        self.client.send_pyobj(message)
+        return_value = self.client.recv_pyobj()
+
+        return return_value
 
-        if isinstance(return_value, Exception):
-            self.logger.info('Mesh successfully send to worker...')
-        else:
-            return return_value
 
 
 def get_free_port():
