@@ -10,6 +10,7 @@ from pathlib import Path
 import os
 import psycopg2
 import docker
+from sqlalchemy import create_engine
 
 try:
     import importlib.resources as pkg_resources
@@ -32,7 +33,8 @@ class DatabaseService(object):
     def __init__(self, *args, **kwargs):
 
         self._shared_dir = None
-        self._workdir = kwargs.get('workdir', None)
+        self._engine = None
+        # self._workdir = kwargs.get('workdir', None)
 
         self.port = kwargs.get('port', 9006)
         self.user = kwargs.get('user', 'admin')
@@ -50,6 +52,17 @@ class DatabaseService(object):
 
         self._volume = None
         self.docker_client = docker.from_env()
+        self.persist_volume = kwargs.get('persist_volume', False)
+
+    @property
+    def engine(self):
+        if self._engine is None:
+            engine = create_engine(
+                f'postgresql://{self.user}:{self.password}@localhost:{self.port}/{self.db_name}',
+                pool_pre_ping=True)
+            engine.dispose()
+            self._engine = engine
+        return self._engine
 
     @property
     def volume(self):
@@ -67,17 +80,17 @@ class DatabaseService(object):
     def volume(self, value):
         self._volume = value
 
-    @property
-    def workdir(self):
-
-        if self._workdir is None:
-            # check if directory exist, otherwise create
-            # data_path = user_data_dir('PySimultanRadiation', 'TU_Wien')
-            data_path = db_path
-            workdir = Path(data_path, 'db', str(self.user))
-            workdir.mkdir(parents=True, exist_ok=True)
-            self._workdir = str(workdir)
-        return self._workdir
+    # @property
+    # def workdir(self):
+    #
+    #     if self._workdir is None:
+    #         # check if directory exist, otherwise create
+    #         # data_path = user_data_dir('PySimultanRadiation', 'TU_Wien')
+    #         data_path = db_path
+    #         workdir = Path(data_path, 'db', str(self.user))
+    #         workdir.mkdir(parents=True, exist_ok=True)
+    #         self._workdir = str(workdir)
+    #     return self._workdir
 
     @property
     def shared_dir(self):
@@ -132,11 +145,11 @@ class DatabaseService(object):
             self.db_compose_file_name = None
             self.running = False
 
-            if config.clean_up:
-                if self.volume is not None:
-                    logger.info(f'Removing volume {self.volume.name}')
-                    self.volume.remove()
-                    self.volume = None
+        if not self.persist_volume:
+            if self.volume is not None:
+                logger.info(f'Removing volume {self.volume.name}')
+                self.volume.remove()
+                self.volume = None
 
     def start_database_service(self):
         logger.info(f"Starting database container on port: {self.port}...")
@@ -178,24 +191,33 @@ class DatabaseService(object):
     def test_connection(self):
 
         try:
-            conn = psycopg2.connect(dbname=self.db_name,
-                                    user=self.user,
-                                    host='localhost',
-                                    port=self.port,
-                                    password=self.password,
-                                    connect_timeout=1)
+            conn = self.get_connection({'connect_timeout': 1})
+            # conn = psycopg2.connect(dbname=self.db_name,
+            #                         user=self.user,
+            #                         host='localhost',
+            #                         port=self.port,
+            #                         password=self.password,
+            #                         connect_timeout=1)
             conn.close()
             return True
         except:
             return False
 
+    def get_connection(self, kwargs):
+        conn = psycopg2.connect(dbname=self.db_name,
+                                user=self.user,
+                                host='localhost',
+                                port=self.port,
+                                password=self.password, **kwargs)
+        return conn
+
 
 class ShadingService(object):
 
     def __init__(self, *args, **kwargs):
 
         self.port = kwargs.get('port')
-        self.workdir = kwargs.get('workdir')
+        # self.workdir = kwargs.get('workdir')
         self.num_workers = kwargs.get('num_workers')
 
         self.frontend_port = kwargs.get('frontend_port', 8006)
@@ -204,6 +226,8 @@ class ShadingService(object):
         self.log_dir = kwargs.get('log_dir', 'logs')
         self.logging_mode = kwargs.get('logging_mode', 'DEBUG')
 
+        self.db_port = kwargs.get('log_dir', 'logs')
+
         self._shared_dir = None
         self._compose_file_name = None
 
@@ -212,6 +236,13 @@ class ShadingService(object):
         self._volume = None
         self.docker_client = docker.from_env()
 
+        # shading_worker ftp_server
+        self.ftp_port_1 = kwargs.get('ftp_port_1')
+        self.ftp_port_2 = kwargs.get('ftp_port_2')
+        self.ftp_passive_ports = kwargs.get('ftp_passive_ports')
+        self.ftp_user = kwargs.get('ftp_user')
+        self.ftp_password = kwargs.get('ftp_password')
+
     @property
     def volume(self):
         if self._volume is None:
@@ -263,12 +294,12 @@ class ShadingService(object):
 
         compose_template = compose_template.replace('<NUM_WORKERS>', str(self.num_workers))
 
-        # database
-        # compose_template = compose_template.replace('<DB_BIND_VOLUME>', str(self.db_dir))
-        # compose_template = compose_template.replace('<DB_PORT>', str(self.db_port))
-        # compose_template = compose_template.replace('<UserDBName>', str(self.user))
-        # compose_template = compose_template.replace('<UserDBPassword>', str(self.password))
-        # compose_template = compose_template.replace('<DBName>', self.db_name)
+        # ftp
+        compose_template = compose_template.replace('<FTP_Port1>', str(self.ftp_port_1))
+        compose_template = compose_template.replace('<FTP_Port2>', str(self.ftp_port_2))
+        compose_template = compose_template.replace('<UserName>', str(self.ftp_user))
+        compose_template = compose_template.replace('<UserPassword>', str(self.ftp_password))
+        compose_template = compose_template.replace('<FTP_PassivePorts>', str(self.ftp_passive_ports))
 
         with open(filename, 'wt') as f_out:
             f_out.write(compose_template)
