@@ -277,8 +277,8 @@ def generate_terrain(hull_mesh, terrain_height, border_dist=150, mesh_size=50):
 
     path = surf_mesh.section(np.array([0, 0, 1]), np.array([0, 0, terrain_height]))
 
-    if path is None:
-        return terrain
+    # if path is None:
+    #     return terrain
 
     # create terrain face:
 
@@ -309,41 +309,44 @@ def generate_terrain(hull_mesh, terrain_height, border_dist=150, mesh_size=50):
 
     el0 = EdgeLoop(edges=[e0, e1, e2, e3], edge_orientations=[1] * 4)
 
-    # simplify path:
-    planar_path, to_3D = path.to_planar()
-    simple_path = planar_path.simplify()
-
-    path = simple_path.to_3D(to_3D)
-
-    # holes
-    points = [None] * path.vertices.shape[0]
-    for i, vertex in enumerate(path.vertices):
-        points[i] = Vertex(position=np.array(vertex))
-
     holes = []
     all_edges = [e0, e1, e2, e3]
     edge_loops = [el0]
 
-    for line in path.entities:
-        # create edges:
-        if not line.closed:
-            continue
+    # simplify path:
+    points = []
+    if path is not None:
 
-        more_simple_path = simplify_path(path.vertices, line.points)
+        planar_path, to_3D = path.to_planar()
+        simple_path = planar_path.simplify()
 
-        # edges = [None] * (line.nodes.shape[0])
-        # for i, node in enumerate(line.nodes):
-        #    edges[i] = Edge(vertices=[points[node[0]], points[node[1]]])
-        edges = [None] * (more_simple_path.__len__())
-        for i in range(more_simple_path.__len__()-1):
-            edges[i] = Edge(vertices=[points[more_simple_path[i]], points[more_simple_path[i+1]]])
+        path = simple_path.to_3D(to_3D)
 
-        edges[i+1] = Edge(vertices=[points[more_simple_path[-1]], points[more_simple_path[0]]])
+        # holes
+        points = [None] * path.vertices.shape[0]
+        for i, vertex in enumerate(path.vertices):
+            points[i] = Vertex(position=np.array(vertex))
 
-        all_edges.extend(edges)
-        edge_loop = EdgeLoop(edges=edges, edge_orientations=[1] * edges.__len__())
-        edge_loops.append(edge_loop)
-        holes.append(edge_loop)
+        for line in path.entities:
+            # create edges:
+            if not line.closed:
+                continue
+
+            more_simple_path = simplify_path(path.vertices, line.points)
+
+            # edges = [None] * (line.nodes.shape[0])
+            # for i, node in enumerate(line.nodes):
+            #    edges[i] = Edge(vertices=[points[node[0]], points[node[1]]])
+            edges = [None] * (more_simple_path.__len__()-1)
+            for i in range(more_simple_path.__len__()-1):
+                edges[i] = Edge(vertices=[points[more_simple_path[i]], points[more_simple_path[i+1]]])
+
+            # edges[i+1] = Edge(vertices=[points[more_simple_path[-1]], points[more_simple_path[0]]])
+
+            all_edges.extend(edges)
+            edge_loop = EdgeLoop(edges=edges, edge_orientations=[1] * edges.__len__())
+            edge_loops.append(edge_loop)
+            holes.append(edge_loop)
 
     terrain_face = Face(name='Terrain', boundary=el0, holes=holes, mesh_size=mesh_size, foi=False)
 
@@ -517,3 +520,21 @@ def simplify_path(vertices, points):
 def cell_data_to_point_data(mesh):
 
     pass
+
+
+def calc_aoi(irradiation_vector, face_normals, deg=True):
+    if deg:
+        return np.rad2deg(np.arccos(
+            np.clip(trimesh.util.diagonal_dot(face_normals, irradiation_vector['irradiation_vector']), -1.0, 1.0)))
+    else:
+        return np.arccos(
+            np.clip(trimesh.util.diagonal_dot(face_normals, irradiation_vector['irradiation_vector']), -1.0, 1.0))
+
+
+
+
+
+
+if __name__ == '__main__':
+
+    pass
